==> mysql-5.6.51.tar.gz: mysql-5.6.51/storage/ndb/src/ndbapi/API.hpp <==
/*
   Copyright (c) 2003, 2010, Oracle and/or its affiliates. All rights reserved.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#ifndef API_H
#define API_H

#include <ndb_global.h>
#include <BlockNumbers.h>
#include <GlobalSignalNumbers.h>
#include <RefConvert.hpp>
#include <NdbOut.hpp>

#include "NdbApiSignal.hpp"
#include "NdbDictionaryImpl.hpp"
#include "NdbRecord.hpp"
#include "NdbUtil.hpp"

#include <Ndb.hpp>
#include <NdbTransaction.hpp>
#include <NdbOperation.hpp>
#include <NdbIndexOperation.hpp>
#include <NdbScanOperation.hpp>
#include <NdbIndexScanOperation.hpp>
#include <NdbIndexStat.hpp>
#include "NdbIndexStatImpl.hpp"
#include <NdbRecAttr.hpp>
#include <NdbReceiver.hpp>
#include <NdbBlob.hpp>
#include <NdbBlobImpl.hpp>
#include <NdbInterpretedCode.hpp>

#include <NdbEventOperation.hpp>
#include "NdbEventOperationImpl.hpp"

#include "NdbQueryBuilder.hpp"
#include "NdbQueryOperation.hpp"
#include "NdbQueryOperationImpl.hpp"

#include <NdbReceiver.hpp>
#include "NdbImpl.hpp"

#include "TransporterFacade.hpp"

#endif

==> mysql-5.7_5.7.11.orig.tar.gz: mysql-5.7.11/storage/ndb/src/ndbapi/API.hpp <==
/*
   Copyright (c) 2003, 2010, Oracle and/or its affiliates. All rights reserved.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; version 2 of the License.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#ifndef API_H
#define API_H

#include <ndb_global.h>
#include <BlockNumbers.h>
#include <GlobalSignalNumbers.h>
#include <RefConvert.hpp>
#include <NdbOut.hpp>

#include "NdbApiSignal.hpp"
#include "NdbDictionaryImpl.hpp"
#include "NdbRecord.hpp"
#include "NdbUtil.hpp"

#include <Ndb.hpp>
#include <NdbTransaction.hpp>
#include <NdbOperation.hpp>
#include <NdbIndexOperation.hpp>
#include <NdbScanOperation.hpp>
#include <NdbIndexScanOperation.hpp>
#include <NdbIndexStat.hpp>
#include "NdbIndexStatImpl.hpp"
#include <NdbRecAttr.hpp>
#include <NdbReceiver.hpp>
#include <NdbBlob.hpp>
#include <NdbBlobImpl.hpp>
#include <NdbInterpretedCode.hpp>
#include <NdbWaitGroup.hpp>

#include <NdbEventOperation.hpp>
#include "NdbEventOperationImpl.hpp"

#include "NdbQueryBuilder.hpp"
#include "NdbQueryOperation.hpp"
#include "NdbQueryOperationImpl.hpp"

#include <NdbReceiver.hpp>
#include "NdbImpl.hpp"

#include "TransporterFacade.hpp"

#endif
